@@ -11,7 +11,7 @@ def paste_default_page(obj, event):
         return
     noLongerProvides(obj, IDefaultPages)
     obj.exclude_from_nav = False
-    obj.reindexObject(idxs=("object_provides", "exclude_from_nav"))
+    obj.reindexObject(idxs=["object_provides", "exclude_from_nav"])
     parent = event.oldParent
     if parent is not None:
         # page was cut from a folder
@@ -22,6 +22,6 @@ def remove_default_page(obj, event):
     """Handle removal of a default page (Procedure / Page) from a folder"""
     noLongerProvides(obj, IDefaultPages)
     obj.exclude_from_nav = False
-    obj.reindexObject(idxs=("object_provides", "exclude_from_nav"))
+    obj.reindexObject(idxs=["object_provides", "exclude_from_nav"])
     folder = obj.aq_parent
     folder.default_page_uid = None
